pub enum JoinType {
Square,
Bevel,
Round,
Miter,
}Expand description
The JoinType enumeration is only needed when offsetting (inflating/shrinking). It isn’t needed for polygon clipping. It specifies how to manage offsetting at convex angled joins. Concave joins will always be offset with a mitered join.
When adding paths to a ClipperOffset object via the AddPaths method, the JoinType parameter must specify one of the following types - Miter, Square, Bevel or Round.
For more details see JoinType.
Variants